@@ -49,7 +49,7 @@ class PrComment:
 
 
 @dataclass
-class PrInfo:  # pylint: disable=too-many-instance-attributes
+class PrInfo:
     """
     Represents a Github pull request.
     """
@@ -134,9 +134,7 @@ async def query_everything(
     head_refs: List[str],
     user_ids: List[str],
     labels: List[str],
-) -> Tuple[
-    str, List[Optional[PrInfo]], Dict[str, str], Dict[str, str], Dict[str, str]
-]:  # pylint: disable=too-many-statements, too-many-locals
+) -> Tuple[str, List[Optional[PrInfo]], Dict[str, str], Dict[str, str], Dict[str, str]]:
     """
     This function does all necessary graphql querying in one request. This dramatically reduces the
     amount of time spent on querying.
@@ -383,19 +381,26 @@ async def query_everything(
 
 
 async def create_pull_requests(
-    github_ep: github.GitHubEndpoint, repo_id: str, prs: List[PrInfo]
+    github_ep: github.GitHubEndpoint,
+    repo_id: str,
+    repo_info: GitHubRepoInfo,
+    fork_info: GitHubRepoInfo,
+    prs: List[PrInfo],
 ) -> None:
     """
     Create all pull requests given in prs and modify them to add the new pr node id and URL.
     """
     inputs = []
     for pr in prs:
+        headRef = (
+            pr.headRef if fork_info.owner == repo_info.owner else f"{fork_info.owner}:{pr.headRef}"
+        )
         inputs.append(
             {
                 "baseRefName": pr.baseRef,
                 "body": pr.body,
                 "clientMutationId": "revup",
-                "headRefName": pr.headRef,
+                "headRefName": headRef,
                 "repositoryId": repo_id,
                 "title": pr.title,
                 "draft": pr.is_draft,
@@ -434,9 +439,7 @@ async def create_pull_requests(
             pr.url = result["url"]
 
 
-async def update_pull_requests(  # pylint: disable=too-many-locals,too-many-statements
-    github_ep: github.GitHubEndpoint, prs: List[PrUpdate]
-) -> None:
+async def update_pull_requests(github_ep: github.GitHubEndpoint, prs: List[PrUpdate]) -> None:
     """
     Update the given pull request contents, and also add reviewers and labels.
     """
